pub struct TimeScaleLoopState {
pub is_repeating: bool,
pub is_reversing: bool,
}Expand description
Provides additional information about the relationship between a real time and a normalized position, taking into account repeat and/or reverse behavior.
Fields
is_repeating: boolWhether or not the position tagged with this state is considered a repetition, i.e. the timeline has completed at least one entire cycle before reaching it.
is_reversing: boolWhether or not the position tagged with this state is on the reverse pass of any cycle, including the first cycle.